# LD_LIBRARY_PATH={your nwjs-sdk's lib} {your nw binary} {your game's folder} --use-gl=egl --ignore-gpu-blacklist --disable-accelerated-2d-canvas --num-raster-threads=2 --remote-debugging-port=9222
LD_LIBRARY_PATH=~/apps/nwjs-sdk-v0.27.6-linux-arm/lib ~/apps/nwjs-sdk-v0.27.6-linux-arm/nw ~/games/Unity/{GAME_NAME}  --use-gl=egl --ignore-gpu-blacklist --disable-accelerated-2d-canvas --num-raster-threads=2 --remote-debugging-port=9222
